@@ -1,6 +1,6 @@
 import os
-
 from mobio.libs.caching import LruCache, StoreType
+from mobio.sdks.admin import MobioAdminSDK
 
 
 class CommonMerchant:
@@ -166,9 +166,76 @@ class Environment:
     KAFKA_BROKER = 'KAFKA_BROKER'
 
 
+class MobioModuleHost:
+    PROFILING_HOST = "profiling_host"
+    PROFILING_APP_API_SERVICE_HOST = "profiling-v4-app-api-service-host"
+    PROFILING_APP_INTERNAL_SERVICE_HOST = "profiling-v4-app-internal-api-service-host"
+    PROFILING_APP_EXTERNAL_SERVICE_HOST = "profiling-v4-app-external-api-service-host"
+
+    USER_EVENT_HOST = "event_host"
+    USER_EVENT_APP_API_SERVICE_HOST = "user-event-app-api-service-host"
+
+    ADS_HOST = "ads_host"
+    ADS_APP_API_SERVICE_HOST = "ads-app-api-service-host"
+
+    AU_HOST = "au_host"
+    AU_APP_API_SERVICE_HOST = "audience-app-api-service-host"
+    AU_v2_APP_API_SERVICE_HOST = "audience-v2-app-api-service-host"
+
+    BASE_HOST = "base_host"
+
+    CHATTOOL_HOST = "chattool_host"
+    CHATTOOL_APP_API_SERVICE_HOST = "chattool-app-api-service-host"
+    CHATTOOL_APP_SOCKET_SERVICE_HOST = "chattool-app-socket-service-host"
+
+    CRM_HOST = "crm_host"
+
+    EMK_HOST = "emk_host"
+    EMK_APP_API_SERVICE_HOST = "emk-app-api-service-host"
+
+    LOYALTY_HOST = "loyalty_host"
+    LOYALTY_API_APP_SERVICE_HOST = "loyalty-api-app-service-host"
+    LOYALTY_API_EXTERNAL_SERVICE_HOST = "loyalty-api-external-service-host"
+    LOYALTY_API_MINIPOS_APP_SERVICE_HOST = "loyalty-api-minipos-app-service-host"
+    LOYALTY_API_MOBILE_APP_SERVICE_HOST = "loyalty-api-mobile-app-service-host"
+    LOYALTY_API_TRANSACTION_APP_SERVICE_HOST = "loyalty-api-transaction-app-service-host"
+
+    MKT_HOST = "mkt_host"
+
+    NM_HOST = "nm_host"
+    NM_APP_API_NOTIFICATION_SERVICE_HOST = "nm-app-api-notification-service-host"
+    NM_APP_API_ONPREMISE_SERVICE_HOST = "nm-app-api-onpremise-service-host"
+    NM_APP_API_SEND_MESSAGE_SERVICE_HOST = "nm-app-api-send-message-service-host"
+    NM_APP_API_SERVICE_HOST = "nm-app-api-service-host"
+    NM_APP_SOCKET_SERVICE_HOST = "nm-app-socket-service-host"
+    NM_APP_WEB_API_SERVICE_HOST = "nm-app-web-api-service-host"
+
+    SALE_HOST = "sale_host"
+    SALE_API_APP_SERVICE_HOST = "sale-api-app-service-host"
+    SALE_API_FILTER_APP_SERVICE_HOST = "sale-api-filter-app-service-host"
+    SALE_API_REPORT_APP_SERVICE_HOST = "sale-api-report-app-service-host"
+
+    SOCIAL_HOST = "social_host"
+    SOCIAL_API_APP_SERVICE_HOST = "social-api-app-service-host"
+    SOCIAL_REPORT_APP_SERVICE_HOST = "social-reports-app-service-host"
+
+    TICKET_HOST = "ticket_host"
+    TICKET_APP_API_SERVICE_HOST = "ticket-app-api-service-host"
+
+
 lru_cache = LruCache(
     store_type=StoreType.REDIS,
     # config_file_name=APP_CONFIG_FILE_PATH,
     cache_prefix="profiling_mf",
     redis_uri=os.getenv(Environment.REDIS_URI),
 )
+
+
+p_mf_admin_sdk = MobioAdminSDK()
+p_mf_admin_sdk.config(
+    admin_host=os.getenv(Environment.ADMIN_HOST),  # admin host
+    redis_uri=os.getenv(Environment.REDIS_URI),  # redis uri
+    module_use="profiling_mf",  # liên hệ admin để khai báo tên của module
+    module_encrypt="gw5HNauilRF1ZqWZhuJeYz6+CuCA4gba752905f7239644e2f20238d3a85fc3",  # liên hệ admin để lấy mã
+    api_admin_version="api/v2.1",  # danh sách api có thể sử dụng ["v1.0", "api/v2.0", "api/v2.1"]
+)
\ No newline at end of file
