@@ -8,7 +8,6 @@ class MergeBirthMonth(BaseMerge):
         profile_data,
         set_suggest_fields,
         set_unique_suggest_values,
-        field_key,
         field_property,
         display_type,
         translate_key,
@@ -25,12 +24,11 @@ class MergeBirthMonth(BaseMerge):
         origin_data,
         set_suggest_fields,
         set_unique_suggest_values,
-        field_key,
         field_property,
         display_type,
         translate_key,
     ):
         pass
 
-    def merge_data(self, target_data, source_data, field_key, is_master_data=False):
+    def merge_data(self, target_data, source_data, is_master_data=False):
         pass
